Struct Array
pub struct Array(/* private fields */);Expand description
A sequence of values.
Implementations
impl Array
impl Array
pub fn with_capacity(capacity: usize) -> Array
pub fn with_capacity(capacity: usize) -> Array
Creates a new vec, with a known capacity.
pub fn first_mut(&mut self) -> Result<&mut Value, EcoString>
pub fn first_mut(&mut self) -> Result<&mut Value, EcoString>
Mutably borrow the first value in the array.
pub fn last_mut(&mut self) -> Result<&mut Value, EcoString>
pub fn last_mut(&mut self) -> Result<&mut Value, EcoString>
Mutably borrow the last value in the array.
impl Array
impl Array
pub fn first(&self, default: Option<Value>) -> Result<Value, EcoString>
pub fn first(&self, default: Option<Value>) -> Result<Value, EcoString>
Returns the first item in the array.
pub fn last(&self, default: Option<Value>) -> Result<Value, EcoString>
pub fn last(&self, default: Option<Value>) -> Result<Value, EcoString>
Returns the last item in the array.
pub fn at(&self, index: i64, default: Option<Value>) -> Result<Value, EcoString>
pub fn at(&self, index: i64, default: Option<Value>) -> Result<Value, EcoString>
Returns the item at the specified index in the array.
pub fn pop(&mut self) -> Result<Value, EcoString>
pub fn pop(&mut self) -> Result<Value, EcoString>
Removes the last item from the array and returns it.
pub fn insert(&mut self, index: i64, value: Value) -> Result<(), EcoString>
pub fn insert(&mut self, index: i64, value: Value) -> Result<(), EcoString>
Inserts a value into the array at the specified index, shifting all subsequent elements to the right.
pub fn remove(
&mut self,
index: i64,
default: Option<Value>,
) -> Result<Value, EcoString>
pub fn remove( &mut self, index: i64, default: Option<Value>, ) -> Result<Value, EcoString>
Removes the value at the specified index from the array and return it.
pub fn slice(
&self,
start: i64,
end: Option<i64>,
count: Option<i64>,
) -> Result<Array, EcoString>
pub fn slice( &self, start: i64, end: Option<i64>, count: Option<i64>, ) -> Result<Array, EcoString>
Extracts a subslice of the array.
pub fn find(
&self,
engine: &mut Engine<'_>,
context: Tracked<'_, Context<'_>>,
searcher: Func,
) -> Result<Option<Value>, EcoVec<SourceDiagnostic>>
pub fn find( &self, engine: &mut Engine<'_>, context: Tracked<'_, Context<'_>>, searcher: Func, ) -> Result<Option<Value>, EcoVec<SourceDiagnostic>>
Searches for an item for which the given function returns {true} and returns the first match or {none} if there is no match.
pub fn position(
&self,
engine: &mut Engine<'_>,
context: Tracked<'_, Context<'_>>,
searcher: Func,
) -> Result<Option<i64>, EcoVec<SourceDiagnostic>>
pub fn position( &self, engine: &mut Engine<'_>, context: Tracked<'_, Context<'_>>, searcher: Func, ) -> Result<Option<i64>, EcoVec<SourceDiagnostic>>
Searches for an item for which the given function returns {true} and returns the index of the first match or {none} if there is no match.
pub fn range(
args: &mut Args,
inclusive: bool,
step: NonZero<i64>,
) -> Result<Array, EcoVec<SourceDiagnostic>>
pub fn range( args: &mut Args, inclusive: bool, step: NonZero<i64>, ) -> Result<Array, EcoVec<SourceDiagnostic>>
Create an array consisting of a sequence of numbers.
pub fn filter(
&self,
engine: &mut Engine<'_>,
context: Tracked<'_, Context<'_>>,
test: Func,
) -> Result<Array, EcoVec<SourceDiagnostic>>
pub fn filter( &self, engine: &mut Engine<'_>, context: Tracked<'_, Context<'_>>, test: Func, ) -> Result<Array, EcoVec<SourceDiagnostic>>
Produces a new array with only the items from the original one for which the given function returns {true}.
pub fn map(
self,
engine: &mut Engine<'_>,
context: Tracked<'_, Context<'_>>,
mapper: Func,
) -> Result<Array, EcoVec<SourceDiagnostic>>
pub fn map( self, engine: &mut Engine<'_>, context: Tracked<'_, Context<'_>>, mapper: Func, ) -> Result<Array, EcoVec<SourceDiagnostic>>
Produces a new array in which all items from the original one were transformed with the given function.
pub fn enumerate(self, start: i64) -> Result<Array, EcoString>
pub fn enumerate(self, start: i64) -> Result<Array, EcoString>
Returns a new array with the values alongside their indices.
pub fn zip(
self,
args: &mut Args,
exact: bool,
) -> Result<Array, EcoVec<SourceDiagnostic>>
pub fn zip( self, args: &mut Args, exact: bool, ) -> Result<Array, EcoVec<SourceDiagnostic>>
Zips the array with other arrays.
pub fn fold(
self,
engine: &mut Engine<'_>,
context: Tracked<'_, Context<'_>>,
init: Value,
folder: Func,
) -> Result<Value, EcoVec<SourceDiagnostic>>
pub fn fold( self, engine: &mut Engine<'_>, context: Tracked<'_, Context<'_>>, init: Value, folder: Func, ) -> Result<Value, EcoVec<SourceDiagnostic>>
Folds all items into a single value using an accumulator function.
pub fn sum(self, default: Option<Value>) -> Result<Value, HintedString>
pub fn sum(self, default: Option<Value>) -> Result<Value, HintedString>
Sums all items (works for all types that can be added).
pub fn product(self, default: Option<Value>) -> Result<Value, HintedString>
pub fn product(self, default: Option<Value>) -> Result<Value, HintedString>
Calculates the product of all items (works for all types that can be multiplied).
pub fn any(
self,
engine: &mut Engine<'_>,
context: Tracked<'_, Context<'_>>,
test: Func,
) -> Result<bool, EcoVec<SourceDiagnostic>>
pub fn any( self, engine: &mut Engine<'_>, context: Tracked<'_, Context<'_>>, test: Func, ) -> Result<bool, EcoVec<SourceDiagnostic>>
Whether the given function returns {true} for any item in the array.
pub fn all(
self,
engine: &mut Engine<'_>,
context: Tracked<'_, Context<'_>>,
test: Func,
) -> Result<bool, EcoVec<SourceDiagnostic>>
pub fn all( self, engine: &mut Engine<'_>, context: Tracked<'_, Context<'_>>, test: Func, ) -> Result<bool, EcoVec<SourceDiagnostic>>
Whether the given function returns {true} for all items in the array.
pub fn join(
self,
separator: Option<Value>,
last: Option<Value>,
default: Option<Value>,
) -> Result<Value, EcoString>
pub fn join( self, separator: Option<Value>, last: Option<Value>, default: Option<Value>, ) -> Result<Value, EcoString>
Combine all items in the array into one.
pub fn intersperse(self, separator: Value) -> Array
pub fn intersperse(self, separator: Value) -> Array
Returns an array with a copy of the separator value placed between adjacent elements.
pub fn chunks(self, chunk_size: NonZero<usize>, exact: bool) -> Array
pub fn chunks(self, chunk_size: NonZero<usize>, exact: bool) -> Array
Splits an array into non-overlapping chunks, starting at the beginning, ending with a single remainder chunk.
pub fn windows(self, window_size: NonZero<usize>) -> Array
pub fn windows(self, window_size: NonZero<usize>) -> Array
Returns sliding windows of window-size elements over an array.
pub fn sorted(
self,
engine: &mut Engine<'_>,
context: Tracked<'_, Context<'_>>,
span: Span,
key: Option<Func>,
by: Option<Func>,
) -> Result<Array, EcoVec<SourceDiagnostic>>
pub fn sorted( self, engine: &mut Engine<'_>, context: Tracked<'_, Context<'_>>, span: Span, key: Option<Func>, by: Option<Func>, ) -> Result<Array, EcoVec<SourceDiagnostic>>
Return a sorted version of this array, optionally by a given key function.