Struct Content
pub struct Content(/* private fields */);Expand description
A piece of document content.
Implementations
impl Content
impl Content
pub fn new<T>(elem: T) -> Contentwhere
T: NativeElement,
pub fn new<T>(elem: T) -> Contentwhere
T: NativeElement,
Creates a new content from an element.
pub fn span(&self) -> Span
pub fn span(&self) -> Span
Get the span of the content.
pub fn labelled_at(&self) -> Span
pub fn labelled_at(&self) -> Span
Get the span where the label is attached.
pub fn located(self, loc: Location) -> Content
pub fn located(self, loc: Location) -> Content
Assigns a location to the content.
This identifies the content and e.g. makes it linkable by
.linked(Destination::Location(loc)).
Useful in combination with [Location::variant].
pub fn set_location(&mut self, location: Location)
pub fn set_location(&mut self, location: Location)
Set the location of the content.
pub fn is_guarded(&self, index: RecipeIndex) -> bool
pub fn is_guarded(&self, index: RecipeIndex) -> bool
Check whether a show rule recipe is disabled.
pub fn guarded(self, index: RecipeIndex) -> Content
pub fn guarded(self, index: RecipeIndex) -> Content
Disable a show rule recipe.
pub fn is_prepared(&self) -> bool
pub fn is_prepared(&self) -> bool
Whether this content has already been prepared.
pub fn mark_prepared(&mut self)
pub fn mark_prepared(&mut self)
Mark this content as prepared.
pub fn get(
&self,
id: u8,
styles: Option<StyleChain<'_>>,
) -> Result<Value, FieldAccessError>
pub fn get( &self, id: u8, styles: Option<StyleChain<'_>>, ) -> Result<Value, FieldAccessError>
Get a field by ID.
This is the preferred way to access fields. However, you can only use it
if you have set the field IDs yourself or are using the field IDs
generated by the #[elem] macro.
pub fn get_by_name(&self, name: &str) -> Result<Value, FieldAccessError>
pub fn get_by_name(&self, name: &str) -> Result<Value, FieldAccessError>
Get a field by name.
If you have access to the field IDs of the element, use Self::get
instead.
pub fn field(&self, id: u8) -> Result<Value, EcoString>
pub fn field(&self, id: u8) -> Result<Value, EcoString>
Get a field by ID, returning a missing field error if it does not exist.
This is the preferred way to access fields. However, you can only use it
if you have set the field IDs yourself or are using the field IDs
generated by the #[elem] macro.
pub fn field_by_name(&self, name: &str) -> Result<Value, EcoString>
pub fn field_by_name(&self, name: &str) -> Result<Value, EcoString>
Get a field by name, returning a missing field error if it does not exist.
If you have access to the field IDs of the element, use Self::field
instead.
pub fn materialize(&mut self, styles: StyleChain<'_>)
pub fn materialize(&mut self, styles: StyleChain<'_>)
Resolve all fields with the styles and save them in-place.
pub fn sequence(iter: impl IntoIterator<Item = Content>) -> Content
pub fn sequence(iter: impl IntoIterator<Item = Content>) -> Content
Create a new sequence element from multiples elements.
pub fn is<T>(&self) -> boolwhere
T: NativeElement,
pub fn is<T>(&self) -> boolwhere
T: NativeElement,
Whether the contained element is of type T.
pub fn to_packed<T>(&self) -> Option<&Packed<T>>where
T: NativeElement,
pub fn to_packed<T>(&self) -> Option<&Packed<T>>where
T: NativeElement,
Downcasts the element to a packed value.
pub fn to_packed_mut<T>(&mut self) -> Option<&mut Packed<T>>where
T: NativeElement,
pub fn to_packed_mut<T>(&mut self) -> Option<&mut Packed<T>>where
T: NativeElement,
Downcasts the element to a mutable packed value.
pub fn into_packed<T>(self) -> Result<Packed<T>, Content>where
T: NativeElement,
pub fn into_packed<T>(self) -> Result<Packed<T>, Content>where
T: NativeElement,
Downcasts the element into an owned packed value.
pub fn unpack<T>(self) -> Result<T, Content>where
T: NativeElement,
pub fn unpack<T>(self) -> Result<T, Content>where
T: NativeElement,
Extract the raw underlying element.
pub fn can<C>(&self) -> boolwhere
C: 'static + ?Sized,
pub fn can<C>(&self) -> boolwhere
C: 'static + ?Sized,
Whether the contained element has the given capability.
pub fn with<C>(&self) -> Option<&C>where
C: 'static + ?Sized,
pub fn with<C>(&self) -> Option<&C>where
C: 'static + ?Sized,
Cast to a trait object if the contained element has the given capability.
pub fn with_mut<C>(&mut self) -> Option<&mut C>where
C: 'static + ?Sized,
pub fn with_mut<C>(&mut self) -> Option<&mut C>where
C: 'static + ?Sized,
Cast to a mutable trait object if the contained element has the given capability.
pub fn sequence_recursive_for_each<'a>(
&'a self,
f: &mut impl FnMut(&'a Content),
)
pub fn sequence_recursive_for_each<'a>( &'a self, f: &mut impl FnMut(&'a Content), )
Also auto expands sequence of sequences into flat sequence
pub fn styled_with_recipe(
self,
engine: &mut Engine<'_>,
context: Tracked<'_, Context<'_>>,
recipe: Recipe,
) -> Result<Content, EcoVec<SourceDiagnostic>>
pub fn styled_with_recipe( self, engine: &mut Engine<'_>, context: Tracked<'_, Context<'_>>, recipe: Recipe, ) -> Result<Content, EcoVec<SourceDiagnostic>>
Style this content with a recipe, eagerly applying it if possible.
pub fn set<E, const I: u8>(
self,
field: Field<E, I>,
value: <E as SettableProperty<I>>::Type,
) -> Contentwhere
E: SettableProperty<I>,
<E as SettableProperty<I>>::Type: Debug + Clone + Hash + Send + Sync + 'static,
pub fn set<E, const I: u8>(
self,
field: Field<E, I>,
value: <E as SettableProperty<I>>::Type,
) -> Contentwhere
E: SettableProperty<I>,
<E as SettableProperty<I>>::Type: Debug + Clone + Hash + Send + Sync + 'static,
Sets a style property on the content.
pub fn styled_with_map(self, styles: Styles) -> Content
pub fn styled_with_map(self, styles: Styles) -> Content
Style this content with a full style map.
pub fn style_in_place(&mut self, styles: Styles)
pub fn style_in_place(&mut self, styles: Styles)
Style this content with a full style map in-place.
pub fn query_first_naive(&self, selector: &Selector) -> Option<Content>
pub fn query_first_naive(&self, selector: &Selector) -> Option<Content>
Queries the content tree for the first element that match the given selector.
This is a naive hack because contextual content and elements produced
in show rules will not be included in the results. It’s used should
be avoided.
pub fn plain_text(&self) -> EcoString
pub fn plain_text(&self) -> EcoString
Extracts the plain text of this content.
pub fn traverse<F, B>(&self, f: &mut F) -> ControlFlow<B>
pub fn traverse<F, B>(&self, f: &mut F) -> ControlFlow<B>
Traverse this content.
impl Content
impl Content