Struct Dict
pub struct Dict(/* private fields */);Expand description
A map from string keys to values.
Implementations
impl Dict
impl Dict
pub fn at_mut(&mut self, key: &str) -> Result<&mut Value, HintedString>
pub fn at_mut(&mut self, key: &str) -> Result<&mut Value, HintedString>
Mutably borrow the value the given key maps to.
pub fn take(&mut self, key: &str) -> Result<Value, EcoString>
pub fn take(&mut self, key: &str) -> Result<Value, EcoString>
Remove the value if the dictionary contains the given key.
pub fn clear(&mut self)
pub fn clear(&mut self)
Clear the dictionary.
pub fn iter(&self) -> Iter<'_, Str, Value>
pub fn iter(&self) -> Iter<'_, Str, Value>
Iterate over pairs of references to the contained keys and values.
pub fn finish(&self, expected: &[&str]) -> Result<(), EcoString>
pub fn finish(&self, expected: &[&str]) -> Result<(), EcoString>
Check if there is any remaining pair, and if so return an “unexpected key” error.
pub fn unexpected_keys( unexpected: Vec<&str>, hint_expected: Option<&[&str]>, ) -> EcoString
impl Dict
impl Dict
pub fn at(&self, key: Str, default: Option<Value>) -> Result<Value, EcoString>
pub fn at(&self, key: Str, default: Option<Value>) -> Result<Value, EcoString>
Returns the value associated with the specified key in the dictionary.
pub fn remove(
&mut self,
key: Str,
default: Option<Value>,
) -> Result<Value, EcoString>
pub fn remove( &mut self, key: Str, default: Option<Value>, ) -> Result<Value, EcoString>
Removes a pair from the dictionary by key and return the value.