Struct Func
pub struct Func { /* private fields */ }Expand description
A mapping from argument values to a return value.
Implementations
impl Func
impl Func
pub fn name(&self) -> Option<&str>
pub fn name(&self) -> Option<&str>
The function’s name (e.g. min).
Returns None if this is an anonymous closure.
pub fn title(&self) -> Option<&'static str>
pub fn title(&self) -> Option<&'static str>
The function’s title case name, for use in documentation (e.g. Minimum).
Returns None if this is a closure.
pub fn contextual(&self) -> Option<bool>
pub fn contextual(&self) -> Option<bool>
Whether the function is known to be contextual.
pub fn params(&self) -> impl Iterator<Item = ParamInfo>
pub fn params(&self) -> impl Iterator<Item = ParamInfo>
Get details about this function’s parameters if available.
pub fn param(&self, name: &str) -> Option<ParamInfo>
pub fn param(&self, name: &str) -> Option<ParamInfo>
Get the parameter info for a parameter with the given name if it exist.
pub fn def_site(&self) -> Option<DefSite>
pub fn def_site(&self) -> Option<DefSite>
Where the function is defined in the Rust source code (only Some(_) if
it is native, and even then it can be None if the function is
generated, like the typed HTML API).
pub fn field(
&self,
field: &str,
sink: impl WarningSink,
) -> Result<&'static Value, EcoString>
pub fn field( &self, field: &str, sink: impl WarningSink, ) -> Result<&'static Value, EcoString>
Get a field from this function’s scope, if possible.
pub fn to_element(&self) -> Option<Element>
pub fn to_element(&self) -> Option<Element>
Extract the element function, if it is one.
pub fn to_plugin(&self) -> Option<&PluginFunc>
pub fn to_plugin(&self) -> Option<&PluginFunc>
Extract the plugin function, if it is one.
pub fn call<A>(
&self,
engine: &mut Engine<'_>,
context: Tracked<'_, Context<'_>>,
args: A,
) -> Result<Value, EcoVec<SourceDiagnostic>>where
A: IntoArgs,
pub fn call<A>(
&self,
engine: &mut Engine<'_>,
context: Tracked<'_, Context<'_>>,
args: A,
) -> Result<Value, EcoVec<SourceDiagnostic>>where
A: IntoArgs,
Call the function with the given context and arguments.
pub fn span(&self) -> Span
pub fn span(&self) -> Span
The function’s span.